pub enum AlertAction {
Print(String),
Webhook(String),
Restart(SingularTarget),
Slack(String),
Discord(String),
Email {
to: String,
subject: String,
},
}Variants
Print(String)
Webhook(String)
Restart(SingularTarget)
Slack(String)
Send a formatted message to a Slack channel via Incoming Webhook.
Discord(String)
Send a formatted message to a Discord channel via Webhook.
Send an email notification via SMTP.